@@ -55,7 +55,7 @@ bool LdapDN::LdapDNPrivate::isValidRDNString(const QString &rdn) const
     }
 
     // Split the rdn into the attribute name and value parts
-    QStringList components = rdn.split(QLatin1Char('='));
+    const QVector<QStringRef> components = rdn.splitRef(QLatin1Char('='));
 
     // We should have exactly two parts
     if (components.size() != 2) {
@@ -154,7 +154,7 @@ QString LdapDN::toString(int depth) const
         dn += rdns.at(rdns.size() - 1 - i) + QLatin1Char(',');
         qCDebug(LDAP_LOG) << "dn =" << dn;
     }
-    dn = dn.left(dn.length() - 1);   // Strip off the extraneous comma
+    dn.truncate(dn.length() - 1);   // Strip off the extraneous comma
 
     return dn;
 }
